@@ -105,7 +105,7 @@ class CmsViews(BaseCmsView):
             [page] = query[:1]
             return page
         except ValueError:
-            raise HTTPNotFound()
+            return None
 
     @reify
     def get_top_nav(self, order_by=('position',)):
@@ -137,6 +137,10 @@ class CmsViews(BaseCmsView):
     @view_config(route_name='content', renderer='cms:templates/content.pt')
     def content(self):
         page = self.get_page(self.request.matchdict['uuid'])
+
+        if not page:
+            raise HTTPNotFound()
+
         if page.linked_pages:
             linked_pages = self.workspace.S(Page).filter(
                 uuid__in=page.linked_pages)
@@ -159,6 +163,9 @@ class CmsViews(BaseCmsView):
         page = self.get_page(
             None, self.request.matchdict['slug'], self.locale)
 
+        if not page:
+            raise HTTPNotFound()
+
         if page.language != self.locale:
             raise HTTPNotFound()
 
